# CHANGELOG

All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/) and [Keep a Changelog](http://keepachangelog.com/).



## Unreleased
---

### New

### Changes

### Fixes

### Breaks


## 1.0.4 - (2021-05-06)
---

### Changes
* chore(doc): Add documentation architecture.


## 1.0.3 - (2021-05-06)
---

## 1.0.2 - (2021-05-06)
---

## 1.0.1 - (2021-05-06)
---

## 1.0.0 - (2021-05-06)
---

### New
* feat: Overhaul architecture.
* Create basic Config class and related logic for loading configurations


### Fixes
* fix: Fix manifest.in for reference.confs


